@@ -1,78 +1,31 @@
+# -*- coding: utf-8; -*-
 """
-Copyright (C) 2004 Sandino Flores Moreno
+Copyright (C) 2007-2013 Guake authors
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) any later version.
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License as
+published by the Free Software Foundation; either version 2 of the
+License, or (at your option) any later version.
 
-This library is distributed in the hope that it will be useful,
+This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
+General Public License for more details.
 
-You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-USA
-
-simplegladeapp.py - Module that provides an object oriented abstraction
-to pygtk and libglade.
-
-    - Adding `object' as base class to SimpleGladeApp class.
-      by Lincoln de Sousa <lincoln@archlinux-br.org>
-
-    - Commenting `setlocale' call to avoid problems with languages with
-      sufixes (as pt_BR.utf8) by Lincoln de Sousa <lincoln@archlinux-br.org>
+You should have received a copy of the GNU General Public
+License along with this program; if not, write to the
+Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+Boston, MA 02110-1301 USA
 """
-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-import pygtk
-pygtk.require('2.0')
-
 import os
 import re
 import sys
 
-import gtk
-import gtk.glade
-import inspect
+import gi
+gi.require_version('Gtk', '3.0')
+from gi.repository import Gtk
+
 import tokenize
-import weakref
-
-__version__ = "1.0"
-__author__ = 'Sandino "tigrux" Flores-Moreno'
-
-
-def bindtextdomain(app_name, locale_dir=None):
-    """
-    Bind the domain represented by app_name to the locale directory locale_dir.
-    It has the effect of loading translations, enabling applications for different
-    languages.
-
-    app_name:
-        a domain to look for translations, tipically the name of an application.
-
-    locale_dir:
-        a directory with locales like locale_dir/lang_isocode/LC_MESSAGES/app_name.mo
-        If omitted or None, then the current binding for app_name is used.
-    """
-    try:
-        import locale
-        import gettext
-        # FIXME: Commented to avoid problems with a .utf8 LANG variable...
-        # locale.setlocale(locale.LC_ALL, "")
-        gettext.bindtextdomain(app_name, locale_dir)
-        gettext.textdomain(app_name)
-        gtk.glade.bindtextdomain(app_name, locale_dir)
-        gtk.glade.textdomain(app_name)
-        gettext.install(app_name, locale_dir, unicode=1)
-    except (IOError, locale.Error) as e:
-        print("Warning", app_name, e)
-        __builtins__.__dict__["_"] = lambda x: x
 
 
 class SimpleGladeApp(object):
@@ -115,15 +68,26 @@ class SimpleGladeApp(object):
                 setattr(self, key, weakref.proxy(value))
             except TypeError:
                 setattr(self, key, value)
+
         self.glade = None
-        self.install_custom_handler(self.custom_handler)
-        self.glade = self.create_glade(self.glade_path, root, domain)
+
+        self.builder = Gtk.Builder()
+        self.builder.add_from_file(self.glade_path)
+        # TODO PORT connect
+        # self.builder.connect_signals(self.custom_handler)
+
         if root:
-            self.main_widget = self.get_widget(root)
+            # TODO PORT remove the next line is not needed Guake shuold not pass an root parameter
+            # this would mess stuff up
+            # self.main_widget = self.builder.get_object("window-root")
+            self.main_widget = self.builder.get_object(root)
+            self.main_widget.show_all()
         else:
             self.main_widget = None
+
+        # self.glade = self.create_glade(self.glade_path, root, domain)
+
         self.normalize_names()
-        self.add_callbacks(self)
         self.new()
 
     def __repr__(self):
@@ -156,7 +120,9 @@ class SimpleGladeApp(object):
             an instance with methods as code of callbacks.
             It means it has methods like on_button1_clicked, on_entry1_activate, etc.
         """
-        self.glade.signal_autoconnect(callbacks_proxy)
+        # TODO PORT connect
+
+        self.builder.connect_signals(callbacks_proxy)
 
     def normalize_names(self):
         """
@@ -168,19 +134,22 @@ class SimpleGladeApp(object):
         prefixes a widget has for each widget.
         """
         for widget in self.get_widgets():
-            widget_name = gtk.Widget.get_name(widget)
-            prefixes_name_l = widget_name.split(":")
-            prefixes = prefixes_name_l[: -1]
-            widget_api_name = prefixes_name_l[-1]
-            widget_api_name = "_".join(re.findall(tokenize.Name, widget_api_name))
-            gtk.Widget.set_name(widget, widget_api_name)
-            if hasattr(self, widget_api_name):
-                raise AttributeError("instance %s already has an attribute %s" %
-                                     (self, widget_api_name))
-            else:
-                setattr(self, widget_api_name, widget)
-                if prefixes:
-                    gtk.Widget.set_data(widget, "prefixes", prefixes)
+            if isinstance(widget, Gtk.Buildable):
+                widget_name = Gtk.Buildable.get_name(widget)
+                prefixes_name_l = widget_name.split(":")
+                prefixes = prefixes_name_l[:-1]
+                widget_api_name = prefixes_name_l[-1]
+                widget_api_name = "_".join(re.findall(tokenize.Name, widget_api_name))
+                widget_name = Gtk.Buildable.set_name(widget, widget_api_name)
+                if hasattr(self, widget_api_name):
+                    raise AttributeError(
+                        "instance %s already has an attribute %s" % (self, widget_api_name)
+                    )
+                else:
+                    setattr(self, widget_api_name, widget)
+                    if prefixes:
+                        # TODO is is a guess
+                        Gtk.Buildable.set_data(widget, "prefixes", prefixes)
 
     def add_prefix_actions(self, prefix_actions_proxy):
         """
@@ -200,9 +169,14 @@ class SimpleGladeApp(object):
         prefix_s = "prefix_"
         prefix_pos = len(prefix_s)
 
-        is_method = lambda t: callable(t[1])
-        is_prefix_action = lambda t: t[0].startswith(prefix_s)
-        drop_prefix = lambda k, w: (k[prefix_pos:], w)
+        def is_method(t):
+            return callable(t[1])
+
+        def is_prefix_action(t):
+            return t[0].startswith(prefix_s)
+
+        def drop_prefix(k, w):
+            return (k[prefix_pos:], w)
 
         members_t = inspect.getmembers(prefix_actions_proxy)
         methods_t = filter(is_method, members_t)
@@ -217,9 +191,7 @@ class SimpleGladeApp(object):
                         prefix_action = prefix_actions_d[prefix]
                         prefix_action(widget)
 
-    def custom_handler(self,
-                       glade, function_name, widget_name,
-                       str1, str2, int1, int2):
+    def custom_handler(self, glade, function_name, widget_name, str1, str2, int1, int2):
         """
         Generic handler for creating custom widgets, internally used to
         enable custom widgets (custom widgets of glade).
@@ -326,7 +298,7 @@ class SimpleGladeApp(object):
         For example, applications based on gstreamer needs to override
         this method with gst.main_quit()
         """
-        gtk.main_quit()
+        Gtk.main_quit()
 
     def run(self):
         """
@@ -356,7 +328,63 @@ class SimpleGladeApp(object):
         return gtk.glade.XML(glade_path, root, domain)
 
     def get_widget(self, widget_name):
-        return self.glade.get_widget(widget_name)
+        return self.builder.get_object(widget_name)
 
     def get_widgets(self):
-        return self.glade.get_widget_prefix("")
+        return self.builder.get_objects()
+
+
+class SimpleGtk3App(object):
+
+    """
+    Basic GtkBuilder wrapper that implements the functions from
+    simplegladeapp.py used by Guake with the purpose to minimize
+    the changes required in Guake while porting it to GtkBuilder.
+    """
+
+    def __init__(self, path):
+        """
+        Load a GtkBuilder ui definition file specified by path.
+        Self will be used as object to to connect the signals.
+        """
+        self.builder = Gtk.Builder()
+        self.builder.add_from_file(path)
+        # TODO PORT connect
+        # self.builder.connect_signals(self)
+
+    def quit(self):
+        """
+        Quit processing of gtk events.
+        """
+        Gtk.main_quit()
+
+    def run(self):
+        """
+        Starts the main gtk loop.
+        """
+        Gtk.main()
+
+    def get_widget(self, name):
+        """
+        Returns the interface widget specified by the name.
+        """
+        return self.builder.get_object(name)
+
+    def get_widgets(self):
+        """
+        Returns all the interface widgets.
+        """
+        return self.builder.get_objects()
+
+    # -- predefined callbacks --
+    def gtk_main_quit(self, *args):
+        """
+        Calls self.quit()
+        """
+        self.quit()
+
+    def gtk_widget_destroy(self, widget, *args):
+        """
+        Destroyes the widget.
+        """
+        widget.destroy()
