@@ -92,8 +92,9 @@ class GuakeTerminal(Vte.Terminal):
     """Just a vte.Terminal with some properties already set.
     """
 
-    def __init__(self, settings):
+    def __init__(self, window, settings):
         super(GuakeTerminal, self).__init__()
+        self.window = window
         self.settings = settings
         self.configure_terminal()
         self.add_matches()
@@ -292,6 +293,9 @@ class GuakeTerminal(Vte.Terminal):
         if event.button == 1 and (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
             if (Vte.MAJOR_VERSION, Vte.MINOR_VERSION) > (0, 50):
                 s = self.hyperlink_check_event(event)
+            else:
+                s = None
+            if s is not None:
                 self._on_ctrl_click_matcher((s, None))
             elif self.get_has_selection():
                 self.quick_open()
@@ -469,9 +473,9 @@ class GuakeTerminalBox(Gtk.HBox):
     """A box to group the terminal and a scrollbar.
     """
 
-    def __init__(self, settings):
+    def __init__(self, window, settings):
         super(GuakeTerminalBox, self).__init__()
-        self.terminal = GuakeTerminal(settings)
+        self.terminal = GuakeTerminal(window, settings)
         self.add_terminal()
         self.add_scroll_bar()
 
